Exception: Rubuild::Build::Dep::Error::Runable

Inherits:
Rubuild::Build::Dep::Error show all
Defined in:
lib/rubuild/build/dep.rb

Overview

Rubuild::Build::Dep::Error::Runable Runable error (dependency tree modified after dependency made runable).

Instance Method Summary collapse

Constructor Details

#initialize(dep, parent) ⇒ Runable

Create a Rubuild::Build::Dep::Error::Runable Used internally. [+dep+] Runable dependency against which the user attempted dependency hierarchy manipulation. [+parent+] Putative parent dependency the user attempted to place in +dep+'s dependency tree.



132
133
134
135
136
137
138
139
# File 'lib/rubuild/build/dep.rb', line 132

def initialize(dep, parent)
  super(
    dep,
    "Parent dependancy #{parent} added to #{dep} " +
      "after dependancy made runable."
    )
  self.rubuild_build_dep_error_runable__parent = parent
end